@@ -6,12 +6,13 @@ from functools import partial, wraps
 
 import component_registry_bindings
 import osidb_bindings
+from osidb_bindings.bindings.python_client.models import Affect, Flaw, Tracker
 from pkg_resources import resource_filename  # type: ignore
 from rich.logging import RichHandler
 
 from griffon.output import console
 
-__version__ = "0.1.11"
+__version__ = "0.1.12"
 
 if "CORGI_API_URL" not in os.environ:
     print("Must set CORGI_API_URL environment variable.")
@@ -22,6 +23,9 @@ if "OSIDB_API_URL" not in os.environ:
     print("Must set OSIDB_API_URL environment variable.")
     exit(1)
 OSIDB_API_URL = os.environ["OSIDB_API_URL"]
+OSIDB_USERNAME = os.getenv("OSIDB_USERNAME", "")
+OSIDB_PASSWORD = os.getenv("OSIDB_PASSWORD", "")
+OSIDB_AUTH_METHOD = os.getenv("OSIDB_AUTH_METHOD", "kerberos")
 
 GRIFFON_CONFIG_DIR = os.getenv("GRIFFON_API_URL", "~/.griffon")
 GRIFFON_RC_FILE = "~/.griffonrc"
@@ -29,6 +33,8 @@ GRIFFON_DEFAULT_LOG_FILE = os.getenv("GRIFFON_DEFAULT_LOG_FILE", "~/.griffon/his
 
 logger = logging.getLogger("griffon")
 
+RELATED_MODELS_MAPPING = {Flaw: {"affects": Affect}, Affect: {"trackers": Tracker}}
+
 
 def config_logging(level="INFO"):
     message_format = "%(asctime)s %(name)s %(levelname)s %(message)s"
@@ -124,7 +130,11 @@ class OSIDBService:
     def create_session():
         """init osidb session"""
         try:
-            return osidb_bindings.new_session(osidb_server_uri=OSIDB_API_URL)
+            credentials = {}
+            if OSIDB_AUTH_METHOD == "credentials":
+                credentials["username"] = OSIDB_USERNAME
+                credentials["password"] = OSIDB_PASSWORD
+            return osidb_bindings.new_session(osidb_server_uri=OSIDB_API_URL, **credentials)
         except:  # noqa
             console.log(f"{OSIDB_API_URL} is not accessible (or krb ticket has expired).")
             exit(1)
@@ -173,6 +183,48 @@ class OSIDBService:
         """get affect impact enum"""
         return osidb_bindings.bindings.python_client.models.ImpactEnum
 
+    @staticmethod
+    def get_flaw_meta_type():
+        """get flaw meta type enum"""
+        return osidb_bindings.bindings.python_client.models.MetaTypeEnum
+
+    @staticmethod
+    def get_fields(model, prefix=""):
+        """
+        get model fields and fields of its related models with
+        respective prefixes using dot notation
+
+        eg. field, related_model.field, related_model_1.related_model2.field
+        """
+
+        # get rid of the self attribute
+        fields = [f"{prefix}{field}" for field in model.get_fields().keys()]
+        for name, related_model in RELATED_MODELS_MAPPING.get(model, {}).items():
+            fields.extend(OSIDBService.get_fields(related_model, prefix=f"{prefix}{name}."))
+
+        return fields
+
+    @staticmethod
+    def get_meta_attr_fields(model, prefix=""):
+        """
+        get model meta attr keys and keys of its related models meta attr with
+        respective prefixes using dot notation
+
+        eg. key, related_model.key, related_model_1.related_model2.key
+        """
+        model_meta_attr = model.get_fields().get("meta_attr")
+        if model_meta_attr is None:
+            return []
+
+        # get rid of the self attribute and add additional wildcard
+        fields = [f"{prefix}{field}" for field in model_meta_attr.get_fields().keys() | {"*"}]
+        for name, related_model in RELATED_MODELS_MAPPING.get(model, {}).items():
+            fields.extend(
+                OSIDBService.get_meta_attr_fields(related_model, prefix=f"{prefix}{name}.")
+            )
+
+        return fields
+
 
 def progress_bar(
     func=None,
